@@ -41,10 +41,10 @@ class Domoticz(IPlugin):
 		idex= location + "_" + on_off
 #		#log.msg("WAMP session data received (transport ID %s): %s" % (self._parent._transportid, payload))
 		log.msg("index :  %s" % (idex))		
-#		for rs in self.configuration_plugin['param_dz']
-#			if rs['ids'] == idex
-#				bodies == rs['boy']
-#				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs['idx'],on_off.capitalize()))
+		for rs in self.configuration_plugin['param_dz']
+			if rs['ids'] == idex
+				bodies == rs['boy']
+				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs['idx'],on_off.capitalize()))
 		return {"plugin": "Domoticz",
 			"method": "switchlight",
 			"body": bodies
